searchData={"items":[{"type":"module","title":"Dependents.Tree","doc":"Converts the `Dependents.Tree` of all or a single app into table maps.\n\nThe dependencies of an app are specified in the `mix.exs` file.\nThe _dependents_ of an app are those apps using it as a dependency.","ref":"Dependents.Tree.html"},{"type":"function","title":"Dependents.Tree.new/0","doc":"","ref":"Dependents.Tree.html#new/0"},{"type":"function","title":"Dependents.Tree.projects_dir/0","doc":"Returns the _projects directory_ as set by environment variable `PROJEX_DIR`.","ref":"Dependents.Tree.html#projects_dir/0"},{"type":"function","title":"Dependents.Tree.to_maps/1","doc":"Converts the `Dependents.Tree` of all or a single app into table maps.","ref":"Dependents.Tree.html#to_maps/1"},{"type":"function","title":"Dependents.Tree.to_maps/2","doc":"","ref":"Dependents.Tree.html#to_maps/2"},{"type":"type","title":"Dependents.Tree.app/0","doc":"Local app","ref":"Dependents.Tree.html#t:app/0"},{"type":"type","title":"Dependents.Tree.dcys/0","doc":"Number of local dependencies","ref":"Dependents.Tree.html#t:dcys/0"},{"type":"type","title":"Dependents.Tree.dep/0","doc":"Local dependent","ref":"Dependents.Tree.html#t:dep/0"},{"type":"type","title":"Dependents.Tree.deps/0","doc":"Number of local dependents","ref":"Dependents.Tree.html#t:deps/0"},{"type":"type","title":"Dependents.Tree.rank/0","doc":"Topological rank","ref":"Dependents.Tree.html#t:rank/0"},{"type":"type","title":"Dependents.Tree.ranks/0","doc":"Ranks of topologically ordered apps","ref":"Dependents.Tree.html#t:ranks/0"},{"type":"type","title":"Dependents.Tree.t/0","doc":"Tree mapping local apps to local dependents","ref":"Dependents.Tree.html#t:t/0"},{"type":"type","title":"Dependents.Tree.table_map/0","doc":"Table map for printing","ref":"Dependents.Tree.html#t:table_map/0"},{"type":"module","title":"Dependents.Tree.CLI","doc":"Parses the command line and prints a `Dependents.Tree` table.","ref":"Dependents.Tree.CLI.html"},{"type":"function","title":"Dependents.Tree.CLI.main/1","doc":"Parses the command line and prints a `Dependents.Tree` table.\n\nThe dependencies of an app are specified in the `mix.exs` file.\nThe _dependents_ of an app are those apps using it as a dependency.\n\n`argv` can be \"-h\" or \"--help\", which prints info on the command's\nusage and syntax. Otherwise it is an apps's directory, to list all\ndirect and indirect _dependents_ of that app. To list dependents\nof all apps, specify switch `--all`.","ref":"Dependents.Tree.CLI.html#main/1"},{"type":"function","title":"Parameters - Dependents.Tree.CLI.main/1","doc":"- `argv` - command line arguments (list)","ref":"Dependents.Tree.CLI.html#main/1-parameters"},{"type":"function","title":"Switches - Dependents.Tree.CLI.main/1","doc":"- `-h` or `--help` - for help\n  - `-a` or `--all`  - to list dependents of all apps","ref":"Dependents.Tree.CLI.html#main/1-switches"},{"type":"module","title":"Dependents.Tree.Digraph","doc":"In a diagram of a graph, a vertex is usually represented by a circle with a\r\nlabel, and an edge is represented by an arrow extending from one vertex to\r\nanother.\r\n\r\nHere vertices are apps and edges are arrows extending from an app to its\r\ndependents.","ref":"Dependents.Tree.Digraph.html"},{"type":"function","title":"Dependents.Tree.Digraph.dependents/2","doc":"Returns a recursive list of the out-neighbors of `app`.\r\n\r\nIf an edge is emanating from v and incident on w, then w is said to be an\r\nout-neighbor of v, and v is said to be an in-neighbor of w.","ref":"Dependents.Tree.Digraph.html#dependents/2"},{"type":"function","title":"Dependents.Tree.Digraph.from_tree/1","doc":"Converts a `Dependents.Tree` into a digraph.","ref":"Dependents.Tree.Digraph.html#from_tree/1"},{"type":"function","title":"Dependents.Tree.Digraph.ranks/1","doc":"Assigns each app (vertex) to its topological rank in `digraph`.","ref":"Dependents.Tree.Digraph.html#ranks/1"},{"type":"type","title":"Dependents.Tree.Digraph.t/0","doc":"Erlang digraph","ref":"Dependents.Tree.Digraph.html#t:t/0"},{"type":"module","title":"Dependents.Tree.DotGraph","doc":"Converts a DOT graph (file `deps_tree.dot`) into a `Dependents.Tree`.\r\nAlso returns the directory of a DOT graph given its path.","ref":"Dependents.Tree.DotGraph.html"},{"type":"function","title":"Dependents.Tree.DotGraph.dir/1","doc":"Returns the directory of a DOT graph (file `deps_tree.dot`) given its `path`.","ref":"Dependents.Tree.DotGraph.html#dir/1"},{"type":"function","title":"Examples - Dependents.Tree.DotGraph.dir/1","doc":"iex> alias Dependents.Tree.DotGraph\r\n    iex> projs_dir = \"c:/Users/Ray/Documents/ex_dev/projects\"\r\n    iex> path1 = \"#{projs_dir}/file_only_logger/deps_tree.dot\"\r\n    iex> path2 = \"#{projs_dir}/file only logger/deps_tree.dot\"\r\n    iex> {DotGraph.dir(path1), DotGraph.dir(path2)}\r\n    {\"file_only_logger\", nil}","ref":"Dependents.Tree.DotGraph.html#dir/1-examples"},{"type":"function","title":"Dependents.Tree.DotGraph.to_tree/2","doc":"Returns the `Dependents.Tree` of a DOT graph.\r\n\r\nA DOT graph line maps an app to a dependency. For example:\r\n\r\n```\r\n\"noaa_observations\"\r\n\"noaa_observations\" -> \"ex_doc\" [label=\"~> 0.22\"]\r\n\"ex_doc\" -> \"earmark_parser\" [label=\"~> 1.4.0\"]\r\n\"noaa_observations\" -> \"io_ansi_table\" [label=\"~> 1.0\"]\r\n\"noaa_observations\" -> \"persist_config\" [label=\"~> 0.4\"]\r\n```\r\n\r\nConverted into a `Dependents.Tree`, the above 5 lines become:\r\n\r\n```\r\n%{\r\n  # Number of local dependencies...\r\n  noaa_observations: [2],\r\n  io_ansi_table: [:noaa_observations],\r\n  persist_config: [:noaa_observations]\r\n}\r\n```","ref":"Dependents.Tree.DotGraph.html#to_tree/2"},{"type":"function","title":"Examples - Dependents.Tree.DotGraph.to_tree/2","doc":"iex> alias Dependents.Tree.DotGraph\r\n    iex> projs_dir = \"c:/Users/Ray/Documents/ex_dev/projects\"\r\n    iex> dir = \"noaa_observations\"\r\n    iex> path = \"#{projs_dir}/#{dir}/deps_tree.dot\"\r\n    iex> dirs = [\"io_ansi_table\", \"log_reset\", \"persist_config\", dir]\r\n    iex> DotGraph.to_tree({path, dir}, dirs)\r\n    %{\r\n      noaa_observations: [3],\r\n      log_reset: [:noaa_observations],\r\n      io_ansi_table: [:noaa_observations],\r\n      persist_config: [:noaa_observations]\r\n    }","ref":"Dependents.Tree.DotGraph.html#to_tree/2-examples"},{"type":"module","title":"Dependents.Tree.Help","doc":"Prints info on the escript command's usage and syntax.","ref":"Dependents.Tree.Help.html"},{"type":"function","title":"Dependents.Tree.Help.show_help/0","doc":"Prints info on the escript command's usage and syntax.","ref":"Dependents.Tree.Help.html#show_help/0"},{"type":"module","title":"Dependents.Tree.Proxy","doc":"Creates a `Dependents.Tree` of all local apps.\nAlso converts a `Dependents.Tree` into table maps.","ref":"Dependents.Tree.Proxy.html"},{"type":"function","title":"Dependents.Tree.Proxy.new/0","doc":"Creates a `Dependents.Tree` of all local apps.","ref":"Dependents.Tree.Proxy.html#new/0"},{"type":"function","title":"Examples - Dependents.Tree.Proxy.new/0","doc":"iex> alias Dependents.Tree.Proxy\n    iex> tree = Proxy.new()\n    iex> %{log_reset: [n1 | deps1], io_ansi_table: [n2 | deps2]} = tree\n    iex> Enum.all?(deps1, &is_atom/1) and Enum.all?(deps2, &is_atom/1) and\n    ...> is_integer(n1) and is_integer(n2)\n    true","ref":"Dependents.Tree.Proxy.html#new/0-examples"},{"type":"function","title":"Dependents.Tree.Proxy.to_maps/2","doc":"Converts a `Dependents.Tree` into table maps.","ref":"Dependents.Tree.Proxy.html#to_maps/2"},{"type":"function","title":"Examples - Dependents.Tree.Proxy.to_maps/2","doc":"iex> alias Dependents.Tree.Proxy\n    iex> tree = %{\n    ...>   io_ansi_table: [3, :noaa_observations, :github_issues],\n    ...>   map_sorter: [4, :io_ansi_table]\n    ...> }\n    iex> ranks = %{io_ansi_table: 27, map_sorter: 25}\n    iex> maps = Proxy.to_maps(tree, ranks)\n    iex> [\n    ...>   %{\n    ...>     app: :io_ansi_table, chunk: 1,\n    ...>     dependent_1: :noaa_observations,\n    ...>     dependent_2: :github_issues,\n    ...>     dependent_3: nil,\n    ...>     dependent_4: nil,\n    ...>     dcys: 3, deps: 2, hex: \"Y\", rank: 27, ver: ver_27\n    ...>   },\n    ...>   %{\n    ...>     app: :map_sorter, chunk: 1,\n    ...>     dependent_1: :io_ansi_table,\n    ...>     dependent_2: nil,\n    ...>     dependent_3: nil,\n    ...>     dependent_4: nil,\n    ...>     dcys: 4, deps: 1, hex: \"Y\", rank: 25, ver: ver_25\n    ...>   }\n    ...> ] = maps\n    iex> is_binary(ver_27) and is_binary(ver_25)\n    true","ref":"Dependents.Tree.Proxy.html#to_maps/2-examples"}],"content_type":"text/markdown"}